@@ -99,7 +99,7 @@ class ImageModelTraining:
 
             try:
                 model = model.to(self.device)
-                outputs = model(inputs)
+                outputs = model(inputs).to(self.device)
             except Exception as e:
                 print(f"Error while running model: {e}")
                 print("Input size:", inputs.size())
